%       ratioP = DegreeOfPolarisation(x, m, ang);
%       
%		Results in ratioP = [magP; P] where
%       Polarisation ratio P and Degree of polarisation magP for the scattered light. 
%
%       In all cases magP <= 1 and P(0)=P(180)=0
%       It is known that if
%               P > 0  ==>  Scattered light is partially polarised parallel to the scattering plane
%               P < 0  ==>  Scattered light is partially polarised perpendicular to the scattering plane
%               



% G. Chliveros and MA Rodrigues (2002), CVPRAI Group, Sheffield Hallam University
% http://www.shu.ac.uk/scis/artificial_intelligence
function [P, magP] = DegreeOfPolarisation(x, m, ang);

S = nlayerAmp(m, x, ang);

% || scattered iradiance per unit incident irradiance assuming incident light polarised perpendicular to the scattering plane
% PerIrradiance = (S(1,:) + S(2,:));
% _|_ scattered iradiance per unit incident irradiance assuming incident light polarised parallel to the scattering plane
% ParIrradiance = (S(1,:) - S(2,:));

% Polarisation Ratio
P = - (S(2,:) ./ S(1,:));
% Degree of Polarisation
magP = abs(P);

figure
plot(ang, magP)

figure
plot(ang, P)