%       Scattering Amplitute Elements of scattered light.
%		nlayerAmp(m,x,Io,ang) returns the scattered Light for
%		a sphere, size x, refractive index relative to medium m
%		at angle ang.
%

% G. Chliveros and MA Rodrigues (2002), CVPRAI Group, Sheffield Hallam University
% http://www.shu.ac.uk/scis/artificial_intelligence
function S = nlayerAmp(m, x, ang)

if length(x)==1
   x = x*ones(size(m));
end
if length(m)==1
   m = m*ones(size(x));
end
% criteria for number of terms in Mie Series 
% (Number of coefficients nlayerScaCoeff to be calculated)
% Wiscombe(1980), Applied Optics, 19(9), 1505
nc = ceil(max(x)+4.05*(max(x)^(1/3))+2);
n=(1:nc).';
E = ((2*nc+1)/(nc*(nc+1)));
[p,t] = ALegendr(ang,nc);
W = warning;
warning off
[a,b] = nlayerScaCoeff(m,x,nc);
% Check for invalid (NaN) results due to too many terms in
% relatively small particles.
invalid = find(any(isnan([a;b])));
while ~isempty(invalid)
   a(:,invalid) = 0;
   b(:,invalid) = 0;
   nc2 = ceil(max(x(invalid))+4.05*(max(x(invalid))^(1/3))+2);
   [A,B] = nlayerScaCoeff(m(invalid),x(invalid),nc2);
   a(1:nc2,invalid) = A;
   b(1:nc2,invalid) = B;
   invalid = find(any(isnan([a;b])));
   % remove invalidity of zero m or x
   % these _should_ return NaN!
   if length(x)>=max(invalid)
      invalid = invalid(x(invalid)~=0);
   else
      if x==0
         invalid = [];
      end
   end
   if length(m)>=max(invalid)
      invalid = invalid(m(invalid)~=0);
   else
      if m==0
         invalid = [];
      end
   end
end
warning(W);

a = a.*E;
b = b.*E;
% The scattering amplitute functions
S1 = a.'*p + b.'*t;
S2 = a.'*t + b.'*p;
% The scattering matrix elements (Mueller Matrix)
S11 = ((S2.*conj(S2))+(S1.*conj(S1)))/2;
S12 = ((S2.*conj(S2))-(S1.*conj(S1)))/2;
S33 = ((S1.*conj(S2))+(S2.*conj(S1)))/2;
S34 = i*((S1.*conj(S2))-(S2.*conj(S1)))/2;

S = [S11; S12; S33; S34];